@@ -1,8 +1,14 @@
-# Copyright (c) 2016-2022 Association of Universities for Research in Astronomy, Inc. (AURA)
+# Copyright (c) 2016-2023 Association of Universities for Research in Astronomy, Inc. (AURA)
 # For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
 
-"""A small version of GPP data model"
 """
+A small version of GPP data model
+"""
+
+from typing import NewType
+
+import numpy.typing as npt
+
 from .atom import *
 from .constraints import *
 from .group import *
@@ -19,9 +25,12 @@ from .target import *
 from .timeallocation import *
 from .timingwindow import *
 from .too import *
+from .wavelength import *
 
-# Type alias for a night index.
-NightIndex = int
-
-# Type alias for multiple night indices.
+# Type alias for a night index and night indices.
+NightIndex = NewType('NightIndex', int)
 NightIndices = npt.NDArray[NightIndex]
+
+# Type alias for a time slot index and time slot indices.
+TimeslotIndex = NewType('TimeslotIndex', int)
+TimeslotIndices = npt.NDArray[TimeslotIndex]
