@@ -1,23 +1,26 @@
-# Copyright (c) 2016-2022 Association of Universities for Research in Astronomy, Inc. (AURA)
+# Copyright (c) 2016-2023 Association of Universities for Research in Astronomy, Inc. (AURA)
 # For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
 
+from __future__ import annotations
+
 from abc import ABC, abstractmethod
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from datetime import timedelta
 from enum import Enum, auto
-from typing import Final, FrozenSet, List, NoReturn, Optional, Union
+from typing import Final, FrozenSet, List, Optional
 
 from lucupy.helpers import flatten
+from lucupy.minimodel.constraints import Constraints
+from lucupy.minimodel.ids import (GroupID, ObservationID, ProgramID,
+                                  UniqueGroupID)
+from lucupy.minimodel.observation import Observation, ObservationClass
+from lucupy.minimodel.resource import Resources
+from lucupy.minimodel.site import Site
+from lucupy.minimodel.wavelength import Wavelengths
 
-from .constraints import Constraints
-from .ids import GroupID, ProgramID, UniqueGroupID
-from .observation import Observation
-from .resource import Resource
-from .site import Site
-from ..types import ZeroTime
+from .observationmode import ObservationMode
 
-
-ROOT_GROUP_ID: Final[str] = 'root'
+ROOT_GROUP_ID: Final[GroupID] = GroupID('root')
 
 
 @dataclass
@@ -36,7 +39,7 @@ class Group(ABC):
                                  considered complete.
         delay_min(timedelta): used in cadences.
         delay_max(timedelta): used in cadences.
-        children (Union[List['Group'], Observation]): member(s) of the group
+        children (Union[List[Group], Observation]): member(s) of the group
     """
     id: GroupID
     program_id: ProgramID
@@ -44,39 +47,54 @@ class Group(ABC):
     number_to_observe: int
     delay_min: timedelta
     delay_max: timedelta
+    children: List[Group] | Observation
 
-    # Cannot be frozen with gelidum.
-    children: Union[List['Group'], Observation]
+    # Calculated afterward.
+    unique_id: UniqueGroupID = field(init=False)
 
     def __post_init__(self):
         if self.number_to_observe <= 0:
             msg = f'Group {self.group_name} specifies non-positive {self.number_to_observe} children to be observed.'
             raise ValueError(msg)
 
-    def unique_id(self) -> UniqueGroupID:
-        """Get a unique name for the group.
-        If this is an observation group, it is just the group_id.
-        If this is a scheduling group, since in OCS this is just an integer, we combine with the program_id to
-            make it unique.
-
-        Returns:
-            UniqueGroupID: A unique identifier for the group.
-        """
-        if self.id.startswith(self.program_id):
-            return self.id
+        if self.id.id.startswith(self.program_id.id):
+            unique_id = self.id.id
         else:
-            return f'{self.program_id}:{self.id}'
+            unique_id = f'{self.program_id.id}:{self.id.id}'
+        object.__setattr__(self, 'unique_id', UniqueGroupID(unique_id))
 
     def subgroup_ids(self) -> FrozenSet[GroupID]:
-        """Get the ids for all the subgroups inside.
+        """Get the ids for all the subgroups inside. This should probably not be used.
 
         Returns:
             FrozenSet[GroupID]: Set of GroupID values.
         """
-        if isinstance(self.children, Observation):
-            return frozenset()
-        else:
-            return frozenset(subgroup.id for subgroup in self.children)
+
+        def aux(group: Group) -> FrozenSet[GroupID]:
+            """
+            Private method to amalgamate all the UniqueIDs starting at a Group.
+            """
+            ids = {group.id}
+            if not isinstance(group.children, Observation):
+                ids |= aux(*[sg for sg in group.children])
+            return frozenset(ids)
+        return aux(self)
+
+    def subgroup_unique_ids(self) -> FrozenSet[UniqueGroupID]:
+        """Get all the unique ids for all the subgroups inside.
+
+        Returns:
+            FrozenSet[UniqueGroupID]: Consists of all the UniqueGroupID for Groups rooted here.
+        """
+        def aux(group: Group) -> FrozenSet[UniqueGroupID]:
+            """
+            Private method to amalgamate all the UniqueIDs starting at a Group.
+            """
+            ids = {group.unique_id}
+            if not isinstance(group.children, Observation):
+                ids |= aux(*[sg for sg in group.children])
+            return frozenset(ids)
+        return aux(self)
 
     def sites(self) -> FrozenSet[Site]:
         """All belonging Sites.
@@ -89,20 +107,20 @@ class Group(ABC):
         else:
             return frozenset.union(*[s.sites() for s in self.children])
 
-    def required_resources(self) -> FrozenSet[Resource]:
+    def required_resources(self) -> Resources:
         """
         Returns:
-            FrozenSet[Resource]: A set of Resources.
+            Resources: A set of Resources.
         """
         if isinstance(self.children, Observation):
             return self.children.required_resources()
         else:
             return frozenset(r for c in self.children for r in c.required_resources())
 
-    def wavelengths(self) -> FrozenSet[float]:
+    def wavelengths(self) -> Wavelengths:
         """
         Returns:
-            FrozenSet[float]: A set of wavelengths.
+            Wavelengths: A set of wavelengths.
         """
         if isinstance(self.children, Observation):
             return self.children.wavelengths()
@@ -122,7 +140,7 @@ class Group(ABC):
     def observations(self) -> List[Observation]:
         """
         Returns:
-            List[Observation]: A set of Observations.
+            List[Observation]: A list of Observations.
         """
         if isinstance(self.children, Observation):
             return [self.children]
@@ -143,6 +161,22 @@ class Group(ABC):
         """
         return not self.is_observation_group()
 
+    @property
+    def to_observation_id(self) -> ObservationID:
+        """
+        A method that, for observation groups, returns the corresponding ObservationID for the observation contained
+        in the group
+
+        If the group is instead a scheduling group, a TypeError will be raised.
+        """
+        if self.is_observation_group():
+            if isinstance(self.children, Observation):
+                return self.children.id
+            else:
+                raise TypeError('Failed is_observation_group method')
+        else:
+            raise TypeError('Cannot get an ObservationID from a scheduling group.')
+
     def exec_time(self) -> timedelta:
         """Total execution time across the children of this group.
 
@@ -152,7 +186,29 @@ class Group(ABC):
         if isinstance(self.children, Observation):
             return self.children.exec_time()
         else:
-            return sum((child.exec_time() for child in self.children), ZeroTime)
+            return sum((child.exec_time() for child in self.children), timedelta())
+
+    def prog_time(self) -> timedelta:
+        """Program time planned across the group.
+
+        Returns:
+            prog_time (timedelta): Sum of all prog_time planned times across children of this group.
+        """
+        if isinstance(self.children, Observation):
+            return self.children.prog_time()
+        else:
+            return sum((child.prog_time() for child in self.children), timedelta())
+
+    def part_time(self) -> timedelta:
+        """Partner time planned across the group.
+
+        Returns:
+            part_time (timedelta): Sum of all `part_time` (planned times) across the children of this group.
+        """
+        if isinstance(self.children, Observation):
+            return self.children.part_time()
+        else:
+            return sum((child.part_time() for child in self.children), timedelta())
 
     def program_used(self) -> timedelta:
         """Program time used across the group.
@@ -163,18 +219,18 @@ class Group(ABC):
         if isinstance(self.children, Observation):
             return self.children.program_used()
         else:
-            return sum((child.program_used() for child in self.children), ZeroTime)
+            return sum((child.program_used() for child in self.children), timedelta())
 
     def partner_used(self) -> timedelta:
         """Partner time used across the group.
 
         Returns:
-            partner_time (timedelta): Sum of all `partner_used` across the children of this group.
+            partner_used (timedelta): Sum of all `partner_used` across the children of this group.
         """
         if isinstance(self.children, Observation):
             return self.children.partner_used()
         else:
-            return sum((child.partner_used() for child in self.children), ZeroTime)
+            return sum((child.partner_used() for child in self.children), timedelta())
 
     def total_used(self) -> timedelta:
         """Total time used across the group: includes program time and partner time.
@@ -185,9 +241,70 @@ class Group(ABC):
         if isinstance(self.children, Observation):
             return self.children.total_used()
         else:
-            return sum((child.total_used() for child in self.children), ZeroTime)
+            return sum((child.total_used() for child in self.children), timedelta())
 
-    def show(self, depth: int = 1) -> NoReturn:
+    def not_charged(self) -> timedelta:
+        """not_charged time across the group.
+
+        Returns:
+            not_charged (timedelta): Sum of all `not_charged` across the children of this group.
+        """
+        if isinstance(self.children, Observation):
+            return self.children.not_charged()
+        else:
+            return sum((child.not_charged() for child in self.children), timedelta())
+
+    def program_observations(self) -> List[Observation]:
+        """Return the list of program (science + program calibration) observations in the group"""
+        observations = []
+        for obs in self.observations():
+            if obs.obs_class in [ObservationClass.SCIENCE, ObservationClass.PROGCAL]:
+                observations.append(obs)
+        return observations
+
+    def partner_observations(self) -> List[Observation]:
+        """Return the list of partner calibration observations in the group"""
+        observations = []
+        for obs in self.observations():
+            if obs.obs_class == ObservationClass.PARTNERCAL:
+                observations.append(obs)
+        return observations
+
+    def daycal_observations(self) -> List[Observation]:
+        """Return the list of daytime calibration observations in the group"""
+        observations = []
+        for obs in self.observations():
+            if obs.obs_class == ObservationClass.DAYCAL:
+                observations.append(obs)
+        return observations
+
+    def obs_class(self) -> ObservationClass:
+        """
+        Determine a group 'obs_class' for observation groups
+        """
+        obs_class = ObservationClass.NONE
+        if self.is_and_group():
+            if isinstance(self.children, Observation):
+                obs_class = self.children.obs_class
+            else:
+                obs_class = min([child.obs_class() for child in self.children])
+        return obs_class
+
+    def obs_mode(self) -> ObservationMode:
+        """
+        Return an observation mode based on those of the children
+        TODO: Consider the case of mixed imaging and spectroscopy groups, maybe this should return a list
+        :return:
+        """
+        obs_mode = ObservationMode.UNKNOWN
+        if self.is_and_group():
+            if isinstance(self.children, Observation):
+                obs_mode = self.children.obs_mode()
+            else:
+                obs_mode = max([child.obs_mode() for child in self.children])
+        return obs_mode
+
+    def show(self, depth: int = 1) -> None:
         """Print content of the Group.
 
         Args:
@@ -198,7 +315,7 @@ class Group(ABC):
 
         # Is this a subgroup or an observation?
         group_type = 'Scheduling Group' if self.is_scheduling_group() else 'Observation Group'
-        print(f'{sep(depth)} Group: {self.id}, unique_id={self.unique_id()} '
+        print(f'{sep(depth)} Group: {self.id.id}, unique_id={self.unique_id.id} '
               f'({group_type}, num_children={len(self.children)})')
         if isinstance(self.children, Observation):
             self.children.show(depth + 1)
@@ -269,19 +386,19 @@ class AndGroup(Group):
     def is_or_group(self) -> bool:
         return False
 
-    def instruments(self) -> FrozenSet[Resource]:
+    def instruments(self) -> Resources:
         """
         Returns:
-            instruments (FrozenSet[Resource]): A set of all instruments used in this group.
+            instruments (Resources): A set of all instruments used in this group.
         """
-        if issubclass(type(self.children), Observation):
+        if isinstance(self.children, Observation):
             instrument = self.children.instrument()
             if instrument is not None:
                 return frozenset({instrument})
             else:
                 return frozenset()
         else:
-            return frozenset(flatten([child.instruments() for child in self.children]))
+            return frozenset(flatten([child.instruments() for child in self.children]))  # type: ignore
 
 
 @dataclass
