@@ -1,22 +1,27 @@
-# Copyright (c) 2016-2022 Association of Universities for Research in Astronomy, Inc. (AURA)
+# Copyright (c) 2016-2023 Association of Universities for Research in Astronomy, Inc. (AURA)
 # For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
 
+from __future__ import annotations
+
 from dataclasses import dataclass
 from datetime import timedelta
 from enum import IntEnum, auto
-from typing import FrozenSet, List, Mapping, NoReturn, Optional
+from typing import List, Mapping, Optional
 
-from lucupy.observatory.abstract import ObservatoryProperties
+import numpy as np
+import numpy.typing as npt
 
 from ..types import ZeroTime
 from .atom import Atom
 from .constraints import Constraints
-from .ids import ObservationID, ProgramID
+from .ids import ObservationID, ProgramID, UniqueGroupID
+from .observationmode import ObservationMode
 from .qastate import QAState
-from .resource import Resource
+from .resource import NIR_INSTRUMENTS, Resource, Resources
 from .site import Site
 from .target import Target, TargetType
 from .too import TooType
+from .wavelength import Wavelengths
 
 
 class ObservationStatus(IntEnum):
@@ -98,6 +103,7 @@ class ObservationClass(IntEnum):
     ACQ = auto()
     ACQCAL = auto()
     DAYCAL = auto()
+    NONE = auto()
 
 
 @dataclass
@@ -121,7 +127,7 @@ class Observation:
             with the base being in the first position
         guiding (Mapping[Resource, Target]): is a map between guide probe resources and their targets.
         sequence (List[Atom]): Sequence of Atoms that describe the observation.
-        belongs_to (ProgramID): Id for the program the observation belongs to.
+        belongs_to (ProgramID): ID for the program the observation belongs to.
         constraints (Constraints, optional): Some observations do not have constraints, e.g. GN-208A-FT-103-6.
         too_type (TooType, optional): Default to None.
 
@@ -153,14 +159,24 @@ class Observation:
     belongs_to: ProgramID
 
     # Some observations do not have constraints, e.g. GN-208A-FT-103-6.
-    constraints: Optional[Constraints]
+    # to mypy complaince we should have an EmptyConstraints
+    constraints: Constraints
 
     too_type: Optional[TooType] = None
 
-    def unique_id(self):
+    @property
+    def to_unique_group_id(self) -> UniqueGroupID:
         """
-        Unique ID for the Observation to make it treatable as a Group.
-        It is simply the same as the ObservationID.
+        A method to return the UniqueGroupID that contains this observation.
+        """
+        return self.id.to_unique_group_id
+
+    @property
+    def unique_id(self) -> ObservationID:
+        """
+        Unique ID for the Observation to amalgamate all the IDs from Group down to Observation.
+        This way, for any group, group.children will return an ID, giving a mixed list of UniqueGroupID and
+        ObservationID, which will be used to select the top level groups.
         """
         return self.id
 
@@ -169,7 +185,11 @@ class Observation:
         Returns:
             Get the base target for this Observation if it has one, and None otherwise.
         """
-        return next(filter(lambda t: t.type == TargetType.BASE, self.targets), None)
+        def filter_by_type(t: Optional[Target]):
+            if t is not None:
+                return t.type == TargetType.BASE
+
+        return next(filter(lambda t: filter_by_type(t), self.targets), None)
 
     def exec_time(self) -> timedelta:
         """
@@ -185,29 +205,40 @@ class Observation:
         """
         return self.program_used() + self.partner_used()
 
-    def required_resources(self) -> FrozenSet[Resource]:
+    def required_resources(self) -> Resources:
         """
         Returns:
             The required resources for an observation based on the sequence's needs.
         """
         # TODO: For now, we do not return guiding keys amongst the resources.
         # return frozenset(self.guiding.keys() | {r for a in self.sequence for r in a.resources})
-        return frozenset((r for a in self.sequence for r in a.resources))
+        return frozenset({self.site.resource} | {r for a in self.sequence for r in a.resources})
 
     def instrument(self) -> Optional[Resource]:
         """
         Returns:
             A resource that is an instrument, if one exists. There should be only one.
         """
-        return next(filter(lambda r: ObservatoryProperties.is_instrument(r),
+        def check_instrument(r: Optional[Resource]):
+            if r is not None:
+                # To avoid a circular import.
+                from lucupy.observatory.abstract import ObservatoryProperties
+                return ObservatoryProperties.is_instrument(r)
+
+        return next(filter(lambda r: check_instrument(r),
                            self.required_resources()), None)
 
-    def wavelengths(self) -> FrozenSet[float]:
+    def is_nir(self) -> bool:
+        """Define if the observation is a NIR observation or not."""
+        inst_req = self.instrument()
+        return any(inst_req == nir_ins for nir_ins in NIR_INSTRUMENTS)
+
+    def wavelengths(self) -> Wavelengths:
         """
         Returns:
             The set of wavelengths included in the sequence.
         """
-        return frozenset((w for c in self.sequence for w in c.wavelengths))
+        return frozenset(w for c in self.sequence for w in c.wavelengths)
 
     def program_used(self) -> timedelta:
         """We roll this information up from the atoms as it will be calculated
@@ -216,7 +247,7 @@ class Observation:
         Returns:
             (timedelta): With the time program used.
         """
-        return sum((atom.prog_time for atom in self.sequence), start=ZeroTime)
+        return sum((atom.program_used for atom in self.sequence), start=ZeroTime)
 
     def partner_used(self) -> timedelta:
         """We roll this information up from the atoms as it will be calculated
@@ -224,14 +255,48 @@ class Observation:
         from the OCS, which is used to populate the time allocation.
 
         Returns:
-            (timedelta): With the time program used.
+            (timedelta): With the time partner used.
         """
-        return sum((atom.part_time for atom in self.sequence), start=ZeroTime)
+        return sum((atom.partner_used for atom in self.sequence), start=ZeroTime)
+
+    def prog_time(self) -> timedelta:
+        """We roll this information up from the atoms.
+
+        Returns:
+            (timedelta): With the total planned program time.
+        """
+        acq_time = ZeroTime
+        if self.obs_class in [ObservationClass.SCIENCE, ObservationClass.PROGCAL]:
+            acq_time = self.acq_overhead
+
+        return sum((atom.prog_time for atom in self.sequence), start=acq_time)
+
+    def part_time(self) -> timedelta:
+        """We roll this information up from the atoms.
+
+        Returns:
+            (timedelta): With the total planned partner time.
+        """
+        acq_time = ZeroTime
+        if self.obs_class in [ObservationClass.PARTNERCAL]:
+            acq_time = self.acq_overhead
+
+        return sum((atom.part_time for atom in self.sequence), start=acq_time)
+
+    def cumulative_exec_times(self) -> npt.NDArray[timedelta]:
+        """Cumulative series of execution times for the unobserved atoms
+        in a sequence, excluding acquisition time."""
+        cum_seq = [atom.exec_time if not atom.observed else ZeroTime for atom in self.sequence]
+        return np.cumsum(cum_seq)
+
+    def not_charged(self) -> timedelta:
+        """not_charged time rolled up from atoms"""
+        return sum((atom.not_charged for atom in self.sequence), start=ZeroTime)
 
     @staticmethod
     def _select_obsclass(classes: List[ObservationClass]) -> Optional[ObservationClass]:
         """Given a list of non-empty ObservationClasses, determine which occurs with
-        highest precedence in the ObservationClasses enum, i.e. has the lowest index.
+        the highest precedence in the ObservationClasses enum, i.e. has the lowest index.
 
         This will be used when examining the sequence for atoms.
 
@@ -245,7 +310,7 @@ class Observation:
     @staticmethod
     def _select_qastate(qastates: List[QAState]) -> Optional[QAState]:
         """
-        Given a list of non-empty QAStates, determine which occurs with
+        Given a list of non-empty QAStates, determine which occurs with the
         highest precedence in the QAStates enum, i.e. has the lowest index.
 
         Returns:
@@ -256,7 +321,10 @@ class Observation:
 
         return min(qastates, default=None)
 
-    def show(self, depth: int = 1) -> NoReturn:
+    def obs_mode(self) -> ObservationMode:
+        return self.sequence[0].obs_mode
+
+    def show(self, depth: int = 1) -> None:
         """Print content of the Observation.
 
         Args:
@@ -265,7 +333,7 @@ class Observation:
         def sep(indent: int) -> str:
             return '-----' * indent
 
-        print(f'{sep(depth)} Observation: {self.id}')
+        print(f'{sep(depth)} Observation: {self.id.id} {self.status.name}')
         for atom in self.sequence:
             print(f'{sep(depth + 1)} {atom}')
 
@@ -276,7 +344,7 @@ class Observation:
         """
         return 1
 
-    def __eq__(self, other: 'Observation') -> bool:
+    def __eq__(self, other: Observation) -> bool:  # type: ignore[override]
         """
         We override the equality checker created by @dataclass to temporarily skip sequence
         comparison in test cases until the atom creation process is finish.
