@@ -1,18 +1,25 @@
-# Copyright (c) 2016-2022 Association of Universities for Research in Astronomy, Inc. (AURA)
+# Copyright (c) 2016-2023 Association of Universities for Research in Astronomy, Inc. (AURA)
 # For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
 
 from dataclasses import dataclass
-from typing import Optional
+from typing import FrozenSet, Optional
 
-from ..decorators import immutable
+from lucupy.decorators import immutable
 
 
 @immutable
 @dataclass(frozen=True)
 class Resource:
     """This is a general observatory resource.
-    It can consist of a guider, an instrument, or a part of an instrument,
-    or even a personnel and is used to determine what observations can be
+    It can consist of
+
+    * a guider;
+    * an instrument;
+    * a part of an instrument;
+    * an observatory (Site); or even
+    * personnel
+
+    and is used to determine what observations can be
     performed at a given time based on the resource availability.
 
     Attributes:
@@ -31,3 +38,12 @@ class Resource:
 
     def __repr__(self):
         return f"Resource(id='{self.id}')"
+
+
+Resources = FrozenSet[Resource]
+
+NIR_INSTRUMENTS: Resources = frozenset([Resource('Flamingos2'),
+                                        Resource('GNIRS'),
+                                        Resource('NIRI'),
+                                        Resource('NIFS'),
+                                        Resource('IGRINS')])
