@@ -1,12 +1,18 @@
-# Copyright (c) 2016-2022 Association of Universities for Research in Astronomy, Inc. (AURA)
+# Copyright (c) 2016-2023 Association of Universities for Research in Astronomy, Inc. (AURA)
 # For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
 
+from __future__ import annotations
+
 from abc import ABC
 from datetime import timedelta
-from typing import FrozenSet, NoReturn, Optional
+from typing import Optional, cast
 
 from astropy.time import Time
 
+from lucupy.minimodel.observationmode import ObservationMode, ObservationModes
+from lucupy.minimodel.resource import Resource, Resources
+from lucupy.minimodel.wavelength import Wavelengths
+
 
 class ObservatoryProperties(ABC):
     """Observatory-specific methods.
@@ -15,10 +21,10 @@ class ObservatoryProperties(ABC):
        structures, and allow computations to be implemented in one place.
 
     """
-    _properties: Optional['ObservatoryProperties'] = None
+    _properties: Optional[ObservatoryProperties] = None
 
     @staticmethod
-    def set_properties(cls) -> NoReturn:
+    def set_properties(cls) -> None:
         """Set properties for an specific Observatory
 
         Raises:
@@ -30,35 +36,33 @@ class ObservatoryProperties(ABC):
         ObservatoryProperties._properties = cls()
 
     @staticmethod
-    def _check_properties() -> NoReturn:
-        """ Check if any properties are set
+    def _check() -> ObservatoryProperties:
+        """ Check if the properties have been set.
 
         Raises:
             ValueError: Properties have not been set.
-
         """
         if ObservatoryProperties._properties is None:
-            raise ValueError('Properties have not been set.')
+            raise ValueError('Observatory properties have not been set.')
+        return cast(ObservatoryProperties, ObservatoryProperties._properties)
 
     @staticmethod
-    def determine_standard_time(resources: FrozenSet,
-                                wavelengths: FrozenSet[float],
-                                modes: FrozenSet,
+    def determine_standard_time(resources: Resources,
+                                wavelengths: Wavelengths,
+                                modes: ObservationModes,
                                 cal_length: int) -> Time:
         """Determine standard time for a specific Observatory
 
         Args:
-            resources (FrozenSet): Set of Resources(instruments, mask, etc).
-            wavelengths (FrozenSet[float]): An array of Wavelengths to be observed.
-            modes (FrozenSet): The different modes of observation.
+            resources (Resources): Set of Resources(instruments, mask, etc).
+            wavelengths (Wavelengths): An array of Wavelengths to be observed.
+            modes (ObservationModes): The different modes of observation.
             cal_length (int): The length (in seconds) of a calibration.
 
         Returns:
             Time: Value(s) of standard time
         """
-
-        ObservatoryProperties._check_properties()
-        return ObservatoryProperties._properties.determine_standard_time(
+        return ObservatoryProperties._check().determine_standard_time(
             resources,
             wavelengths,
             modes,
@@ -66,7 +70,7 @@ class ObservatoryProperties(ABC):
         )
 
     @staticmethod
-    def is_instrument(resource) -> bool:
+    def is_instrument(resource: Resource) -> bool:
         """Determine if the given resource is an instrument or not.
 
         Args:
@@ -75,11 +79,11 @@ class ObservatoryProperties(ABC):
         Returns:
             bool: True is the resource is an instrument of the Observatory, otherwise False.
         """
-        ObservatoryProperties._check_properties()
-        return ObservatoryProperties._properties.is_instrument(resource)
+        return ObservatoryProperties._check().is_instrument(resource)
 
     @staticmethod
-    def acquisition_time(resource, observation_mode) -> Optional[timedelta]:
+    def acquisition_time(resource: Resource,
+                         observation_mode: ObservationMode) -> Optional[timedelta]:
         """Given a resource, check if it is an instrument, and if so, lookup the
            acquisition time for the specified mode.
 
@@ -90,5 +94,4 @@ class ObservatoryProperties(ABC):
         Returns:
             Optional[timedelta]: The acquisition time for the instrument in that specific mode.
         """
-        ObservatoryProperties._check_properties()
-        return ObservatoryProperties._properties.acquisition_time(resource, observation_mode)
+        return ObservatoryProperties._check().acquisition_time(resource, observation_mode)
