@@ -1,14 +1,13 @@
-# Copyright (c) 2016-2022 Association of Universities for Research in Astronomy, Inc. (AURA)
+# Copyright (c) 2016-2023 Association of Universities for Research in Astronomy, Inc. (AURA)
 # For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
 
-from datetime import timedelta
 from enum import Enum, EnumMeta
-from typing import FrozenSet, Optional
 
 import astropy.units as u
 from astropy.time import Time
 
-from lucupy.minimodel import ObservationMode, Resource
+from lucupy.minimodel import (ObservationMode, ObservationModes, Resource,
+                              Resources, Wavelengths)
 from lucupy.observatory.abstract import ObservatoryProperties
 
 
@@ -17,10 +16,10 @@ class GeminiProperties(ObservatoryProperties):
     """
 
     class _InstrumentsMeta(EnumMeta):
-        """Meta class for the Instruments Class below.
+        """Metaclass for the Instruments Class below.
         """
-        def __contains__(cls, r: Resource) -> bool:
-            return any(inst.value.id in r.id for inst in cls.__members__.values())
+        def __contains__(cls, r: Resource) -> bool:  # type: ignore[override]
+            return any(inst.value.id in r.id for inst in cls.__members__.values())  # type: ignore[var-annotated]
 
     class Instruments(Enum, metaclass=_InstrumentsMeta):
         """ Gemini-specific instruments.
@@ -43,16 +42,16 @@ class GeminiProperties(ObservatoryProperties):
     """
 
     @staticmethod
-    def determine_standard_time(resources: FrozenSet[Resource],
-                                wavelengths: FrozenSet[float],
-                                modes: FrozenSet[ObservationMode],
+    def determine_standard_time(resources: Resources,
+                                wavelengths: Wavelengths,
+                                modes: ObservationModes,
                                 cal_length: int) -> Time:
         """Determine the standard star time required for Gemini.
 
         Args:
-            resources (FrozenSet[Resource]): Instruments to be used.
-            wavelengths (FrozenSet[float]): Wavelengths to be observed.
-            modes (FrozenSet[ObservationMode]): Observation modes.
+            resources (Resources): Instruments to be used.
+            wavelengths (Wavelength): Wavelengths to be observed.
+            modes (ObservationModes): Observation modes.
             cal_length (int): The specific length of a calibration.
 
         Returns:
@@ -87,7 +86,8 @@ class GeminiProperties(ObservatoryProperties):
         return resource in GeminiProperties.Instruments
 
     @staticmethod
-    def acquisition_time(resource, observation_mode) -> Optional[timedelta]:
+    def acquisition_time(resource: Resource,
+                         observation_mode: ObservationMode) -> None:
         """_summary_
 
         Args:
