@@ -58,8 +58,8 @@ class Altitude:
 
         """
 
-        dec = np.asarray(dec.to_value(u.rad).data) * u.rad
-        ha = np.asarray(ha.to_value(u.rad)) * u.rad
+        dec = np.asarray(dec.to_value(u.rad).data) * u.rad  # type: ignore
+        ha = np.asarray(ha.to_value(u.rad)) * u.rad  # type: ignore
         scalar_input = False
         if dec.ndim == 0 and ha.ndim == 0:
             scalar_input = True
