@@ -63,7 +63,7 @@ def calculate_sky_brightness(moon_phase_angle: Angle,
 
     # Correction for twilight
     i = np.where(sun_alt > -18.5 * u.deg)[0][:]
-    if len(i) != 0:
+    if len(i):
         v_zen[i] = v_zen[i] - ztwilight(sun_alt[i])
 
     # zenith sky brightness
