@@ -13,7 +13,7 @@ import astropy.units as u
 import numpy as np
 from astropy.coordinates import Angle, EarthLocation
 from astropy.time import Time
-from pytz import timezone
+from pytz import BaseTzInfo
 
 from lucupy.types import TimeScalarOrNDArray
 
@@ -23,13 +23,13 @@ from .sun import Sun
 from .utils import local_midnight_time
 
 
-def night_events(time: Time, location: EarthLocation, localtzone: timezone) -> Tuple[Time,
-                                                                                     TimeScalarOrNDArray,
-                                                                                     TimeScalarOrNDArray,
-                                                                                     TimeScalarOrNDArray,
-                                                                                     TimeScalarOrNDArray,
-                                                                                     TimeScalarOrNDArray,
-                                                                                     TimeScalarOrNDArray]:
+def night_events(time: Time, location: EarthLocation, localtzone: BaseTzInfo) -> Tuple[Time,
+                                                                                       TimeScalarOrNDArray,
+                                                                                       TimeScalarOrNDArray,
+                                                                                       TimeScalarOrNDArray,
+                                                                                       TimeScalarOrNDArray,
+                                                                                       TimeScalarOrNDArray,
+                                                                                       TimeScalarOrNDArray]:
     """Compute phenomena for a given night.
     This is mostly a testbed that prints results directly.
 
