@@ -7,7 +7,7 @@
 # Copyright John Thorstensen, 2018, who graciously has allowed Gemini to use this code under the BSD-3 Clause license.
 # For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
 
-from typing import NoReturn, Optional, Tuple
+from typing import Optional, Tuple
 
 import astropy.units as u
 import numpy as np
@@ -16,13 +16,13 @@ from astropy.coordinates import (Angle, Distance, EarthLocation,
 from astropy.time import Time, TimeDelta
 
 from .altitude import Altitude
-from .constants import EQUAT_RAD, JYEAR, JYEAR_100, J2000
+from .constants import EQUAT_RAD, J2000, JYEAR, JYEAR_100
 from .utils import (current_geocent_frame, geocentric_coors,
                     hour_angle_to_angle, local_sidereal_time)
 
 
 class Moon:
-    """Interface for night events for the moon an other calculations.
+    """Interface for night events for the moon on other calculations.
 
     To use this is required to chain the `at` method at the beginning.
     If not unhandled errors would happen.
@@ -71,7 +71,7 @@ class Moon:
 
         return self
 
-    def _low_precision_calculations(self) -> NoReturn:
+    def _low_precision_calculations(self) -> None:
         """Compute low precision values for the moon location method calculations.
         """
         t = (self.time_jd - J2000) / JYEAR_100  # jul cent. since J2000.0
@@ -97,7 +97,7 @@ class Moon:
                + 0.0028 * np.cos(np.deg2rad(269.9 + 954397.70 * t)))
         self.pie = np.deg2rad(pie)
 
-    def _high_precision_calculations(self) -> NoReturn:
+    def _high_precision_calculations(self) -> None:
         """Compute accurate precession values for the moon location method calculations.
         """
         t = (self.time_ttjd - 2415020.) / JYEAR_100  # this based around 1900 ... */
@@ -110,12 +110,12 @@ class Moon:
         f = 11.250889 + 483202.0251 * t - 0.003211 * t_2 - 0.0000003 * t_3
         om = 259.183275 - 1934.1420 * t + 0.002078 * t_2 + 0.0000022 * t_3
 
-        lpr = lpr % 360.
-        mpr = mpr % 360.
-        m = m % 360.
-        d = d % 360.
-        f = f % 360.
-        om = om % 360.
+        lpr %= 360.
+        mpr %= 360.
+        m %= 360.
+        d %= 360.
+        f %= 360.
+        om %= 360.
 
         sinx = np.sin(np.deg2rad(51.2 + 20.2 * t))
         lpr = lpr + 0.000233 * sinx
@@ -364,9 +364,9 @@ class Moon:
         xobs, yobs, zobs = geocentric_coors(local_sidereal_time(self.time, obs), obs.lat, obs.height)
 
         # recenter moon's cartesian coordinates on position of obs
-        x = x - xobs
-        y = y - yobs
-        z = z - zobs
+        x -= xobs
+        y -= yobs
+        z -= zobs
 
         # form the toposcentric ra and dec and bundle them into a skycoord of epoch of date.
         topo_dist = np.sqrt(x ** 2 + y ** 2 + z ** 2)
@@ -390,7 +390,7 @@ class Moon:
         quickly.
 
         Args:
-            alt: If array, then must be the same length as time_guess desired altitude.
+            alt: If it is an array, then it must be the same length as time_guess desired altitude.
             time_guess : Initial guess; this needs to be fairly close.
             location : EarthLocation
 
